<?php

/**
 * Adds SWA widget.
 */
class SWA_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'swa_widget', // Base ID
			__( 'SWA', 'text_domain' ), // Name
			array( 'description' => __( 'Show SWA Ads', 'text_domain' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		$swa = swa();
		$ads = $swa->get_ads();

		if( $ads ) {

			$top_ads = $ads['top'];
			$bottom_ads = $ads['bottom'];
			$merged_ads = array_merge( $top_ads, $bottom_ads );

			if( count( $merged_ads ) > 0 ) {
				$random_ad = array_rand( $merged_ads );
				$the_random_ad = $top_ads[ $random_ad ];
				swa_set_impressions( $the_random_ad ); 

				echo $args['before_widget'];

				$ad_meta = get_post_meta( $the_random_ad['id'], 'swa_info', true );
				
				$link = $ad_meta['link'];

				echo '<div class="swa_ad">';
					echo '<a data-id="' . $the_random_ad['id'] . '" target="_blank" href="' . $link . '">';
						echo get_the_post_thumbnail( $the_random_ad['id'], 'full' );
						echo '<p>' . $the_random_ad['post_title'] . '</p>';
					echo '</a>';
				echo '</div>';
				
				echo $args['after_widget'];
			}
		}	
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		
		// No need for a form when randomly displaying the Ad
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		// No need for an update function
	}

} 